@@ -250,9 +250,37 @@ class PartnersClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DescribeAgentDealsCache(self, request):
+    def DescribeAgentDealsByCache(self, request):
         """供超大型代理商（代客数量>=3000 ）拉取缓存的全量客户订单。
 
+        :param request: Request instance for DescribeAgentDealsByCache.
+        :type request: :class:`tencentcloud.partners.v20180321.models.DescribeAgentDealsByCacheRequest`
+        :rtype: :class:`tencentcloud.partners.v20180321.models.DescribeAgentDealsByCacheResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeAgentDealsByCache", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeAgentDealsByCacheResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeAgentDealsCache(self, request):
+        """【该接口将逐步下线，请切换使用升级版本DescribeAgentDealsByCache】供超大型代理商（代客数量>=3000 ）拉取缓存的全量客户订单。
+
         :param request: Request instance for DescribeAgentDealsCache.
         :type request: :class:`tencentcloud.partners.v20180321.models.DescribeAgentDealsCacheRequest`
         :rtype: :class:`tencentcloud.partners.v20180321.models.DescribeAgentDealsCacheResponse`
@@ -279,7 +307,7 @@ class PartnersClient(AbstractClient):
 
 
     def DescribeAgentPayDeals(self, request):
-        """可以查询代理商代付的所有订单
+        """【该接口将逐步下线，请切换使用升级版本DescribeAgentPayDealsV2】可以查询代理商代付的所有订单
 
         :param request: Request instance for DescribeAgentPayDeals.
         :type request: :class:`tencentcloud.partners.v20180321.models.DescribeAgentPayDealsRequest`
@@ -306,8 +334,36 @@ class PartnersClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeAgentPayDealsV2(self, request):
+        """可以查询代理商代付的所有订单
+
+        :param request: Request instance for DescribeAgentPayDealsV2.
+        :type request: :class:`tencentcloud.partners.v20180321.models.DescribeAgentPayDealsV2Request`
+        :rtype: :class:`tencentcloud.partners.v20180321.models.DescribeAgentPayDealsV2Response`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeAgentPayDealsV2", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeAgentPayDealsV2Response()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeAgentSelfPayDeals(self, request):
-        """可以查询代理商下指定客户的自付订单
+        """【该接口将逐步下线，请切换使用升级版本DescribeAgentSelfPayDealsV2】可以查询代理商下指定客户的自付订单
 
         :param request: Request instance for DescribeAgentSelfPayDeals.
         :type request: :class:`tencentcloud.partners.v20180321.models.DescribeAgentSelfPayDealsRequest`
@@ -334,6 +390,34 @@ class PartnersClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeAgentSelfPayDealsV2(self, request):
+        """可以查询代理商下指定客户的自付订单
+
+        :param request: Request instance for DescribeAgentSelfPayDealsV2.
+        :type request: :class:`tencentcloud.partners.v20180321.models.DescribeAgentSelfPayDealsV2Request`
+        :rtype: :class:`tencentcloud.partners.v20180321.models.DescribeAgentSelfPayDealsV2Response`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeAgentSelfPayDealsV2", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeAgentSelfPayDealsV2Response()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeClientBalance(self, request):
         """为合作伙伴提供查询客户余额能力。调用者必须是合作伙伴，只能查询自己名下客户余额
 
@@ -362,6 +446,34 @@ class PartnersClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeClientBaseInfo(self, request):
+        """国际站根据UIN查询代客基础信息
+
+        :param request: Request instance for DescribeClientBaseInfo.
+        :type request: :class:`tencentcloud.partners.v20180321.models.DescribeClientBaseInfoRequest`
+        :rtype: :class:`tencentcloud.partners.v20180321.models.DescribeClientBaseInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeClientBaseInfo", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeClientBaseInfoResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeRebateInfos(self, request):
         """代理商可查询自己名下全部返佣信息
 
